@@ -729,13 +729,7 @@ and eval_simple_variable conf =
   | "prefix" -> Util.commd conf
   | "prefix_base" ->
       conf.command ^ "?" ^ (if conf.cgi then "b=" ^ conf.bname ^ ";" else "")
-  | "referer" -> do {
-      let s = Wserver.extract_param "referer: " '\n' conf.request in
-      for i = 0 to String.length s - 1 do {
-        if s.[i] = '&' then s.[i] := ';' else ();
-      };
-      s
-    }
+  | "referer" -> Util.get_referer conf
   | "right" -> conf.right
   | "setup_link" -> if conf.setup_link then " - " ^ setup_link conf else ""
   | "sp" -> " "
@@ -1057,10 +1051,6 @@ value print_body_prop conf =
   Wserver.wprint "%s" (s ^ Util.body_prop conf)
 ;
 
-value print_css_prop conf =
-  Wserver.wprint "%s" (Util.css_prop conf)
-;
-
 type vother 'a =
   [ Vdef of list string and list ast
   | Vval of expr_val 'a
@@ -1266,6 +1256,13 @@ value print_copyright conf =
     } ]
 ;
 
+value print_copyright_with_logo conf =
+  let conf =
+     {(conf) with env = [("with_logo", "yes") :: conf.env]}
+  in
+  print_copyright conf
+;
+
 value old_include_hed_trl conf base_opt suff =
   let hed_fname =
     let fname = Util.base_path ["lang"; conf.lang] (conf.bname ^ suff) in
@@ -1473,8 +1470,8 @@ and print_simple_variable conf base_opt =
   [ "base_header" -> include_hed_trl conf base_opt "hed"
   | "base_trailer" -> include_hed_trl conf base_opt "trl"
   | "body_prop" -> print_body_prop conf
-  | "css_prop" -> print_css_prop conf
-  | "copyright" -> print_copyright conf
+  | "copyright" -> print_copyright_with_logo conf
+  | "copyright_nologo" -> print_copyright conf
   | "hidden" -> Util.hidden_env conf
   | "message_to_wizard" -> Util.message_to_wizard conf
   | _ -> raise Not_found ]
